@@ -1,8 +1,8 @@
 httpget_session_tar <- function(sessionpath, requri){
   setwd(sessionpath);
   tmptar <- tempfile(fileext=".tar.gz");
-  tar(tmptar, files=sessionpath, compression="gzip");
-  
+  tar(tmptar, files=".", compression="gzip");
+
   #continue
   res$setbody(file=tmptar);
   res$setheader("Content-Type", "application/x-gzip")
